@@ -10,11 +10,21 @@ register(
     entry_point='gym_pool.envs:PoolEnv'
 )
 
+register(
+    id='Pool_continuous-v0',
+    entry_point='gym_pool.envs:PoolEnvCon'
+)
+
 register(
     id='Pool3-v0',
     entry_point='gym_pool.envs:PoolEnv3'
 )
 
+register(
+    id='Pool-v1',
+    entry_point='gym_pool.envs:PoolEnvNew'
+)
+
 #register(
 #    id='SoccerAgainstKeeper-v0',
 #    entry_point='gym.envs:SoccerAgainstKeeperEnv',
