@@ -3,22 +3,23 @@ import math
 import random
 from pprint import pprint
 from enum import Enum
+import time
 import os
 
 import numpy as np
 import pygame
 import zope.event
 
-from . import ball
-from . import config
-from . import cue
-from . import cue_visible
-from . import event
-from . import graphics
-from . import table_sprites
-from .ball import BallType
-from .collisions import check_if_ball_touches_balls
-from . import collisions
+import gym_pool.envs.ball as ball
+import gym_pool.envs.config as config
+import gym_pool.envs.cue as cue
+import gym_pool.envs.cue_visible as cue_visible
+import gym_pool.envs.event as event
+import gym_pool.envs.graphics as graphics
+import gym_pool.envs.table_sprites as table_sprites
+from gym_pool.envs.ball import BallType
+from gym_pool.envs.collisions import check_if_ball_touches_balls
+import gym_pool.envs.collisions as collisions
 
 
 class Player(Enum):
@@ -455,7 +456,7 @@ class GameState:
         angle = np.arccos(dot_product)
         return angle
 
-    def step(self, game, angle, force):
+    def step(self, game, angle, force,new_state_space=True):
         original_pos = self.return_ball_state()
         self.collision_count_old = self.collision_count
         self.white_in_old = self.white_in
@@ -507,5 +508,8 @@ class GameState:
         x = len(new_pos)
         for i in range(x, self.ball_num):
             new_pos.append((0, 0))
+        if not new_state_space:
+            collision_count = self.collision_count
+            return (new_pos, balls_in, collision_count, done)
         #distance, position and angle should be def in there
         return (pos_dict, balls_in, self.collision_count-self.collision_count_old, self.white_in-self.white_in_old, self.eight_in-self.eight_in_old, done)
