@@ -3,23 +3,22 @@ import math
 import random
 from pprint import pprint
 from enum import Enum
-import time
 import os
 
 import numpy as np
 import pygame
 import zope.event
 
-import gym_pool.envs.ball as ball
-import gym_pool.envs.config as config
-import gym_pool.envs.cue as cue
-import gym_pool.envs.cue_visible as cue_visible
-import gym_pool.envs.event as event
-import gym_pool.envs.graphics as graphics
-import gym_pool.envs.table_sprites as table_sprites
-from gym_pool.envs.ball import BallType
-from gym_pool.envs.collisions import check_if_ball_touches_balls
-import gym_pool.envs.collisions as collisions
+from . import ball
+from . import config
+from . import cue
+from . import cue_visible
+from . import event
+from . import graphics
+from . import table_sprites
+from .ball import BallType
+from .collisions import check_if_ball_touches_balls
+from . import collisions
 
 
 class Player(Enum):
@@ -49,6 +48,7 @@ class GameState:
         self.eight_in=0
         self.fps_clock = pygame.time.Clock()
         self.start_pool(ball_num)
+        self.holes_xy = np.array([[(x[0], y[0]) for x in self.holes_x] for y in self.holes_y]).reshape(2,6)
         events = event.events()
         self.redraw_all()
 
@@ -116,12 +116,11 @@ class GameState:
         self.reset_state()
         self.generate_table()
         self.set_pool_balls(ball_num)
-        self.cue = cue_visible.Cue(self.white_ball)
-        #if not self.visualize:
-        #    self.cue = cue.Cue(self.white_ball)
-        #else:
+        if not self.visualize:
+            self.cue = cue.Cue(self.white_ball)
+        else:
             #self.cue = cue_visible.Cue(self.white_ball)
-        #    self.cue = cue.Cue(self.white_ball)
+            self.cue = cue.Cue(self.white_ball)
         self.all_sprites.add(self.cue)
 
     def reset_state(self):
@@ -181,8 +180,6 @@ class GameState:
                                               2, 2), (config.resolution[0] - config.table_margin, 3)]
         self.holes_y = [(config.table_margin, 1),
                    (config.resolution[1] - config.table_margin, 2)]
-        print('holes x', self.holes_x)
-        print('holes y', self.holes_y)
         # next three lines are a hack to make and arrange the hole coordinates
         # in the correct sequence
         all_hole_positions = np.array(
@@ -431,7 +428,8 @@ class GameState:
                 for x in self.holes_x:
                     state[key].append(self.euclidean_distance((x[0], y[0]), state[key][0]))
                     state[key].append(self.angle((x[0], y[0]), state[key][0]))
-                #break
+                    break
+                break
         # for k,b in pos_dict.items():
         #   print(k,b)
         state = list(state.items())
@@ -440,10 +438,13 @@ class GameState:
             try:
                 self.balls.sprites()[i].number
                 #full_state += [state[i][1][0][0], state[i][1][0][1]] + state[i][1][1:]
+                #print(state[i][1][1:])
                 full_state += state[i][1][1:]
             except:
-                full_state += [0,0,0,0,0,0,0,0,]
+                full_state += [0 for i in range(len(state[0][1][1:]))]
+            #print(full_state)
         full_state = np.array(full_state).flatten()
+        #print(full_state)
         return full_state
 
     def euclidean_distance(self, point1, point2):
@@ -456,7 +457,7 @@ class GameState:
         angle = np.arccos(dot_product)
         return angle
 
-    def step(self, game, angle, force,new_state_space=True):
+    def step(self, game, angle, force):
         original_pos = self.return_ball_state()
         self.collision_count_old = self.collision_count
         self.white_in_old = self.white_in
@@ -478,6 +479,7 @@ class GameState:
 
         fp = (force - force_in_min) / (force_in_max - force_in_min)
         real_force = fp * (force_out_max - force_out_min) + force_out_min
+        #print(real_force)
 
         events = event.events()
         game.cue.update_cue_displacement(real_force)  # replace 100 with the real input for displacement between 0, 100
@@ -508,8 +510,29 @@ class GameState:
         x = len(new_pos)
         for i in range(x, self.ball_num):
             new_pos.append((0, 0))
-        if not new_state_space:
-            collision_count = self.collision_count
-            return (new_pos, balls_in, collision_count, done)
         #distance, position and angle should be def in there
-        return (pos_dict, balls_in, self.collision_count-self.collision_count_old, self.white_in-self.white_in_old, self.eight_in-self.eight_in_old, done)
+
+        state = {}
+        for i in range(0, len(self.balls.sprites())):
+            currentBall = (self.balls.sprites()[i].ball.pos[0], self.balls.sprites()[i].ball.pos[1])
+            state[self.balls.sprites()[i].number] = [currentBall]
+
+        bd=[]
+        for key in state.keys():
+            if key == 0:
+                continue
+            else:
+                d=[]
+                for xy in self.holes_xy:
+                    d.append(self.euclidean_distance(state[key][0], xy))
+                d=min(d)
+                bd.append(d)
+        if len(bd)>=1:
+            smallest_distance=min(1,1/min(bd))
+            total_distance=min(1,1/sum(bd))
+        else:
+            smallest_distance=1
+            total_distance=1
+        #print(smallest_distance,total_distance)
+
+        return pos_dict, balls_in, self.collision_count-self.collision_count_old, self.white_in-self.white_in_old, self.eight_in-self.eight_in_old, smallest_distance, total_distance, done
